@@ -3,11 +3,11 @@ from typing import List, Iterator, Union
 
 import requests
 
-import nlpsandboxsdk
-from nlpsandboxsdk.models import (
+import nlpsandbox
+from nlpsandbox.models import (
     Annotation, AnnotationStore, Dataset, Note, Tool
 )
-from nlpsandboxsdk.api import (
+from nlpsandbox.api import (
     annotation_store_api, annotation_api, dataset_api, note_api,
     text_contact_annotation_api,
     text_covid_symptom_annotation_api,
@@ -46,10 +46,10 @@ def list_notes(host: str, dataset_id: str, fhir_store_id: str) -> List[dict]:
             "note_name": "dataset/awesome-dataset/fhirStores/awesome-fhirstore/fhir/Note/noteid"
         }
     """
-    configuration = nlpsandboxsdk.Configuration(host=host)
+    configuration = nlpsandbox.Configuration(host=host)
     offset = 0
     limit = 10
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    with nlpsandbox.ApiClient(configuration) as api_client:
         note_instance = note_api.NoteApi(api_client)
         # Obtain all clinical notes
         next_page = True
@@ -91,8 +91,8 @@ def get_annotation_store(host: str, dataset_id: str,
         >>> )
 
     """
-    configuration = nlpsandboxsdk.Configuration(host=host)
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    configuration = nlpsandbox.Configuration(host=host)
+    with nlpsandbox.ApiClient(configuration) as api_client:
         annot_store_instance = annotation_store_api.AnnotationStoreApi(
             api_client
         )
@@ -101,7 +101,7 @@ def get_annotation_store(host: str, dataset_id: str,
             annotation_store_obj = annot_store_instance.get_annotation_store(
                 dataset_id, annotation_store_id
             )
-        except nlpsandboxsdk.rest.ApiException as err:
+        except nlpsandbox.rest.ApiException as err:
             if err.status == 404 and create_if_missing:
                 annotation_store_obj = annot_store_instance.create_annotation_store(
                     dataset_id, annotation_store_id, body={}
@@ -133,8 +133,8 @@ def get_annotation(host: str, dataset_id: str,
         >>> )
 
     """
-    configuration = nlpsandboxsdk.Configuration(host=host)
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    configuration = nlpsandbox.Configuration(host=host)
+    with nlpsandbox.ApiClient(configuration) as api_client:
         annot_instance = annotation_api.AnnotationApi(
             api_client
         )
@@ -190,8 +190,8 @@ def _store_annotation(host: str, dataset_id: str, annotation_store_id: str,
 
     """
 
-    configuration = nlpsandboxsdk.Configuration(host=host)
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    configuration = nlpsandbox.Configuration(host=host)
+    with nlpsandbox.ApiClient(configuration) as api_client:
         annotation_instance = annotation_api.AnnotationApi(api_client)
         new_annotation = utils.change_keys(annotation,
                                            utils.camelcase_to_snakecase)
@@ -223,10 +223,10 @@ def list_annotations(host: str, dataset_id: str,
         >>>                                annotation_store_id="awesome-annotation-store")
 
     """
-    configuration = nlpsandboxsdk.Configuration(host=host)
+    configuration = nlpsandbox.Configuration(host=host)
     offset = 0
     limit = 10
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    with nlpsandbox.ApiClient(configuration) as api_client:
         annotation_instance = annotation_api.AnnotationApi(api_client)
         next_page = True
         while next_page:
@@ -264,8 +264,8 @@ def _annotate_person_name(api_client, text_annotation_request: dict) -> dict:
         >>>    }
         >>> }
         >>> host = "0.0.0.0/api/v1"
-        >>> configuration = nlpsandboxsdk.Configuration(host=host)
-        >>> with nlpsandboxsdk.ApiClient(configuration) as api_client:
+        >>> configuration = nlpsandbox.Configuration(host=host)
+        >>> with nlpsandbox.ApiClient(configuration) as api_client:
         >>>     annotations = _annotate_person_name(
         >>>         api_client=api_client,
         >>>         text_annotation_request=example_request
@@ -300,8 +300,8 @@ def _annotate_physical_address(api_client, text_annotation_request: dict) -> dic
         >>>    }
         >>> }
         >>> host = "0.0.0.0/api/v1"
-        >>> configuration = nlpsandboxsdk.Configuration(host=host)
-        >>> with nlpsandboxsdk.ApiClient(configuration) as api_client:
+        >>> configuration = nlpsandbox.Configuration(host=host)
+        >>> with nlpsandbox.ApiClient(configuration) as api_client:
         >>>     annotations = _annotate_physical_address(
         >>>         api_client=api_client,
         >>>         text_annotation_request=example_request
@@ -336,8 +336,8 @@ def _annotate_date(api_client, text_annotation_request: dict) -> dict:
         >>>    }
         >>> }
         >>> host = "0.0.0.0/api/v1"
-        >>> configuration = nlpsandboxsdk.Configuration(host=host)
-        >>> with nlpsandboxsdk.ApiClient(configuration) as api_client:
+        >>> configuration = nlpsandbox.Configuration(host=host)
+        >>> with nlpsandbox.ApiClient(configuration) as api_client:
         >>>     annotations = _annotate_person(
         >>>         api_client=api_client,
         >>>         text_annotation_request=example_request
@@ -372,8 +372,8 @@ def _annotate_contact(api_client, text_annotation_request: dict) -> dict:
         >>>    }
         >>> }
         >>> host = "0.0.0.0/api/v1"
-        >>> configuration = nlpsandboxsdk.Configuration(host=host)
-        >>> with nlpsandboxsdk.ApiClient(configuration) as api_client:
+        >>> configuration = nlpsandbox.Configuration(host=host)
+        >>> with nlpsandbox.ApiClient(configuration) as api_client:
         >>>     annotations = _annotate_contact(
         >>>         api_client=api_client,
         >>>         text_annotation_request=example_request
@@ -410,8 +410,8 @@ def _annotate_id(api_client, text_annotation_request: dict) -> dict:
         >>>    }
         >>> }
         >>> host = "0.0.0.0/api/v1"
-        >>> configuration = nlpsandboxsdk.Configuration(host=host)
-        >>> with nlpsandboxsdk.ApiClient(configuration) as api_client:
+        >>> configuration = nlpsandbox.Configuration(host=host)
+        >>> with nlpsandbox.ApiClient(configuration) as api_client:
         >>>     annotations = _annotate_id(
         >>>         api_client=api_client,
         >>>         text_annotation_request=example_request
@@ -448,8 +448,8 @@ def _annotate_covid_symptom(api_client, text_annotation_request: dict) -> dict:
         >>>    }
         >>> }
         >>> host = "0.0.0.0/api/v1"
-        >>> configuration = nlpsandboxsdk.Configuration(host=host)
-        >>> with nlpsandboxsdk.ApiClient(configuration) as api_client:
+        >>> configuration = nlpsandbox.Configuration(host=host)
+        >>> with nlpsandbox.ApiClient(configuration) as api_client:
         >>>     annotations = _annotate_covid_symptom(
         >>>         api_client=api_client,
         >>>         text_annotation_request=example_request
@@ -473,7 +473,7 @@ def annotate_note(host: str, note: Union[dict, Note],
     Args:
         host: Data node host IP
         note: Clinical note
-        tool_type: Type of nlpsandboxsdk
+        tool_type: Type of annotator
 
     Yields:
         Annotated notes
@@ -491,30 +491,30 @@ def annotate_note(host: str, note: Union[dict, Note],
 
     """
     # host = "http://10.23.55.45:9000/api/v1"
-    configuration = nlpsandboxsdk.Configuration(host=host)
+    configuration = nlpsandbox.Configuration(host=host)
     # Change clinical note into text annotation request format
     if isinstance(note, Note):
-        text_nlpsandboxsdk_req = {"note": note.to_dict()}
+        text_annotator_req = {"note": note.to_dict()}
     else:
-        text_nlpsandboxsdk_req = {
+        text_annotator_req = {
             "note": utils.change_keys(note, utils.camelcase_to_snakecase)
         }
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    with nlpsandbox.ApiClient(configuration) as api_client:
         if tool_type == "nlpsandbox:date-annotator":
-            annotations = _annotate_date(api_client, text_nlpsandboxsdk_req)
+            annotations = _annotate_date(api_client, text_annotator_req)
         elif tool_type == "nlpsandbox:person-name-annotator":
-            annotations = _annotate_person_name(api_client, text_nlpsandboxsdk_req)
+            annotations = _annotate_person_name(api_client, text_annotator_req)
         elif tool_type == "nlpsandbox:physical-address-annotator":
-            annotations = _annotate_physical_address(api_client, text_nlpsandboxsdk_req)
+            annotations = _annotate_physical_address(api_client, text_annotator_req)
         elif tool_type == "nlpsandbox:contact-annotator":
-            annotations = _annotate_contact(api_client, text_nlpsandboxsdk_req)
+            annotations = _annotate_contact(api_client, text_annotator_req)
         elif tool_type == "nlpsandbox:id-annotator":
-            annotations = _annotate_id(api_client, text_nlpsandboxsdk_req)
+            annotations = _annotate_id(api_client, text_annotator_req)
         elif tool_type == "nlpsandbox:covid-symptom-annotator":
             annotations = _annotate_covid_symptom(api_client,
-                                                  text_nlpsandboxsdk_req)
+                                                  text_annotator_req)
         else:
-            raise ValueError(f"Invalid nlpsandboxsdk_type: {tool_type}")
+            raise ValueError(f"Invalid annotator_type: {tool_type}")
         sanitized_annotations = api_client.sanitize_for_serialization(
             annotations
         )
@@ -538,8 +538,8 @@ def get_tool(host: str) -> Tool:
 
     """
     # host = "http://10.23.55.45:9000/api/v1"
-    configuration = nlpsandboxsdk.Configuration(host=host)
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    configuration = nlpsandbox.Configuration(host=host)
+    with nlpsandbox.ApiClient(configuration) as api_client:
         tool_instance = tool_api.ToolApi(api_client)
         tool_info = tool_instance.get_tool()
     # check if tool / redirects to /tool path
@@ -565,10 +565,10 @@ def list_datasets(host: str) -> List[dict]:
         >>>    "name": "datasets/testing"
         >>> }
     """
-    configuration = nlpsandboxsdk.Configuration(host=host)
+    configuration = nlpsandbox.Configuration(host=host)
     offset = 0
     limit = 10
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    with nlpsandbox.ApiClient(configuration) as api_client:
         api_instance = dataset_api.DatasetApi(api_client)
         # Obtain all clinical notes
         next_page = True
@@ -594,7 +594,7 @@ def _get_tool_redirect(host: str) -> Tool:
         Service object
 
     Examples:
-        >>> tool = get_nlpsandboxsdk(host="0.0.0.0/api/v1")
+        >>> tool = _get_tool_redirect(host="0.0.0.0/api/v1")
 
     """
 
@@ -624,8 +624,8 @@ def store_annotations(host: str, dataset_id: str, annotation_store_id: str,
         delete_existing_annotations: To delete existing annotation store.
                                      Default is True.
     """
-    configuration = nlpsandboxsdk.Configuration(host=host)
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    configuration = nlpsandbox.Configuration(host=host)
+    with nlpsandbox.ApiClient(configuration) as api_client:
         annot_store_instance = annotation_store_api.AnnotationStoreApi(
             api_client
         )
@@ -637,14 +637,14 @@ def store_annotations(host: str, dataset_id: str, annotation_store_id: str,
                     dataset_id, annotation_store_id
                 )
                 print("Deleted existing Annotation Store")
-        except nlpsandboxsdk.rest.ApiException:
+        except nlpsandbox.rest.ApiException:
             pass
         try:
             annot_store_instance.create_annotation_store(
                 dataset_id, annotation_store_id, body={}
             )
             print("Created Annotation Store")
-        except nlpsandboxsdk.rest.ApiException:
+        except nlpsandbox.rest.ApiException:
             print("Using existing Annotation Store")
 
     for annotation in annotations:
@@ -662,9 +662,9 @@ def store_annotations(host: str, dataset_id: str, annotation_store_id: str,
 
 def store_dataset(host: str, dataset_id: str) -> Dataset:
     """Creates a dataset"""
-    configuration = nlpsandboxsdk.Configuration(host=host)
+    configuration = nlpsandbox.Configuration(host=host)
     # Enter a context with an instance of the API client
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    with nlpsandbox.ApiClient(configuration) as api_client:
         # Create an instance of the API class
         api_instance = dataset_api.DatasetApi(api_client)
         body = {}
@@ -674,9 +674,9 @@ def store_dataset(host: str, dataset_id: str) -> Dataset:
 
 def delete_dataset(host: str, dataset_id: str):
     """Deletes a dataset"""
-    configuration = nlpsandboxsdk.Configuration(host=host)
+    configuration = nlpsandbox.Configuration(host=host)
     # Enter a context with an instance of the API client
-    with nlpsandboxsdk.ApiClient(configuration) as api_client:
+    with nlpsandbox.ApiClient(configuration) as api_client:
         # Create an instance of the API class
         api_instance = dataset_api.DatasetApi(api_client)
         api_instance.delete_dataset(dataset_id)
